# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.116
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from helix_platform_api_public_client.models.nomination_gates_overview_response import NominationGatesOverviewResponse  # noqa: E501

class TestNominationGatesOverviewResponse(unittest.TestCase):
    """NominationGatesOverviewResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> NominationGatesOverviewResponse:
        """Test NominationGatesOverviewResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `NominationGatesOverviewResponse`
        """
        model = NominationGatesOverviewResponse()  # noqa: E501
        if include_optional:
            return NominationGatesOverviewResponse(
                long_term = helix_platform_api_public_client.models.nomination_gates_overview_response_long_term.NominationGatesOverviewResponse_longTerm(
                    gate = helix_platform_api_public_client.models.long_term_or_day_ahead_nomination_gate.LongTermOrDayAheadNominationGate(
                        delivery_day = 'Tue Jan 04 00:00:00 UTC 2022', 
                        timescale = 'LONG_TERM', 
                        status = 'OPEN', ), 
                    next_action_at = '2022-01-04T00:00Z', ),
                day_ahead = helix_platform_api_public_client.models.nomination_gates_overview_response_day_ahead.NominationGatesOverviewResponse_dayAhead(
                    gate = helix_platform_api_public_client.models.long_term_or_day_ahead_nomination_gate.LongTermOrDayAheadNominationGate(
                        delivery_day = 'Tue Jan 04 00:00:00 UTC 2022', 
                        timescale = 'LONG_TERM', 
                        status = 'OPEN', ), 
                    next_action_at = '2022-01-04T00:00Z', ),
                intra_day = [
                    helix_platform_api_public_client.models.nomination_gates_overview_response_intra_day.NominationGatesOverviewResponse_intraDay(
                        gate = helix_platform_api_public_client.models.intra_day_nomination_gate.IntraDayNominationGate(
                            id = 'bf325375-e030-fccb-a009-17317c574773:0762-06-86', 
                            product_type = 'ID_01', 
                            name = '', 
                            delivery_day = 'Tue Jan 04 00:00:00 UTC 2022', 
                            mtu_period = helix_platform_api_public_client.models.local_mtu_period.LocalMtuPeriod(
                                from_mtu_start = '10:00', 
                                to_mtu_end = '18:00', ), 
                            status = 'OPEN', ), 
                        next_action_at = '2022-01-04T00:00Z', )
                    ]
            )
        else:
            return NominationGatesOverviewResponse(
                long_term = helix_platform_api_public_client.models.nomination_gates_overview_response_long_term.NominationGatesOverviewResponse_longTerm(
                    gate = helix_platform_api_public_client.models.long_term_or_day_ahead_nomination_gate.LongTermOrDayAheadNominationGate(
                        delivery_day = 'Tue Jan 04 00:00:00 UTC 2022', 
                        timescale = 'LONG_TERM', 
                        status = 'OPEN', ), 
                    next_action_at = '2022-01-04T00:00Z', ),
                day_ahead = helix_platform_api_public_client.models.nomination_gates_overview_response_day_ahead.NominationGatesOverviewResponse_dayAhead(
                    gate = helix_platform_api_public_client.models.long_term_or_day_ahead_nomination_gate.LongTermOrDayAheadNominationGate(
                        delivery_day = 'Tue Jan 04 00:00:00 UTC 2022', 
                        timescale = 'LONG_TERM', 
                        status = 'OPEN', ), 
                    next_action_at = '2022-01-04T00:00Z', ),
                intra_day = [
                    helix_platform_api_public_client.models.nomination_gates_overview_response_intra_day.NominationGatesOverviewResponse_intraDay(
                        gate = helix_platform_api_public_client.models.intra_day_nomination_gate.IntraDayNominationGate(
                            id = 'bf325375-e030-fccb-a009-17317c574773:0762-06-86', 
                            product_type = 'ID_01', 
                            name = '', 
                            delivery_day = 'Tue Jan 04 00:00:00 UTC 2022', 
                            mtu_period = helix_platform_api_public_client.models.local_mtu_period.LocalMtuPeriod(
                                from_mtu_start = '10:00', 
                                to_mtu_end = '18:00', ), 
                            status = 'OPEN', ), 
                        next_action_at = '2022-01-04T00:00Z', )
                    ],
        )
        """

    def testNominationGatesOverviewResponse(self):
        """Test NominationGatesOverviewResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.116
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from helix_platform_api_public_client.models.audit_log import AuditLog  # noqa: E501

class TestAuditLog(unittest.TestCase):
    """AuditLog unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AuditLog:
        """Test AuditLog
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AuditLog`
        """
        model = AuditLog()  # noqa: E501
        if include_optional:
            return AuditLog(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                created_at = '2022-01-04T00:00Z',
                user = helix_platform_api_public_client.models.audit_log_user.AuditLogUser(
                    id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                    name = '', 
                    role = 'ICO_ADMIN', 
                    organisation = helix_platform_api_public_client.models.audit_log_user_organisation.AuditLogUserOrganisation(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        name = '', ), ),
                domain = 'NTC_MANAGEMENT',
                type = 'SUBMIT_NTC',
                status = 'SUCCESS',
                description = '',
                impersonated_by_user = helix_platform_api_public_client.models.audit_log_user.AuditLogUser(
                    id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                    name = '', 
                    role = 'ICO_ADMIN', 
                    organisation = helix_platform_api_public_client.models.audit_log_user_organisation.AuditLogUserOrganisation(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        name = '', ), ),
                requested_with_api_key = helix_platform_api_public_client.models.audit_log_api_key.AuditLogApiKey(
                    id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                    name = '', 
                    created_at = '2022-01-04T00:00Z', )
            )
        else:
            return AuditLog(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                created_at = '2022-01-04T00:00Z',
                user = helix_platform_api_public_client.models.audit_log_user.AuditLogUser(
                    id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                    name = '', 
                    role = 'ICO_ADMIN', 
                    organisation = helix_platform_api_public_client.models.audit_log_user_organisation.AuditLogUserOrganisation(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        name = '', ), ),
                domain = 'NTC_MANAGEMENT',
                type = 'SUBMIT_NTC',
                status = 'SUCCESS',
                description = '',
        )
        """

    def testAuditLog(self):
        """Test AuditLog"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.116
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, constr, validator

class LocalMtuPeriod(BaseModel):
    """
    Period of MTUs in local time aligned to MTU borders in a natural way, meaning:  * with 60 min MTUs if start is 10:00 and end is 11:00 => it means a single MTU between 10:00 and 11:00 * with 30 min MTUs if start is 10:00 and end is 11:00 => it means the two MTUs between 10:00-10:30 and 10:30-11:00   # noqa: E501
    """
    from_mtu_start: constr(strict=True) = Field(..., alias="fromMtuStart", description="The first moment (inclusive) of an MTU period in local time, minute resolution, interpreted in **System Time**  - string, interpreted in `hh:mm` format - only `XX:00`, `XX:15`, `XX:30` and `XX:45` are valid values (depending on MTU size) ")
    to_mtu_end: constr(strict=True) = Field(..., alias="toMtuEnd", description="The last moment (exclusive) of an MTU period in local time, minute resolution, interpreted in **System Time**  - string, interpreted in `hh:mm` format - only `XX:00`, `XX:15`, `XX:30` and `XX:45` are valid values (depending on MTU size) ")
    __properties = ["fromMtuStart", "toMtuEnd"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> LocalMtuPeriod:
        """Create an instance of LocalMtuPeriod from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> LocalMtuPeriod:
        """Create an instance of LocalMtuPeriod from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return LocalMtuPeriod.parse_obj(obj)

        _obj = LocalMtuPeriod.parse_obj({
            "from_mtu_start": obj.get("fromMtuStart"),
            "to_mtu_end": obj.get("toMtuEnd")
        })
        return _obj





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.116
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class MessageSeverity(str, Enum):
    """
    MessageSeverity
    """

    """
    allowed enum values
    """
    CRITICAL_ALERT = 'CRITICAL_ALERT'
    CRITICAL = 'CRITICAL'
    MAJOR = 'MAJOR'
    NORMAL = 'NORMAL'

    @classmethod
    def from_json(cls, json_str: str) -> MessageSeverity:
        """Create an instance of MessageSeverity from a JSON string"""
        return MessageSeverity(json.loads(json_str))





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.116
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from helix_platform_api_public_client.models.audit_log_api_key import AuditLogApiKey
from helix_platform_api_public_client.models.audit_log_domain import AuditLogDomain
from helix_platform_api_public_client.models.audit_log_status import AuditLogStatus
from helix_platform_api_public_client.models.audit_log_type import AuditLogType
from helix_platform_api_public_client.models.audit_log_user import AuditLogUser

class AuditLog(BaseModel):
    """
    AuditLog
    """
    id: StrictStr = Field(..., description="Unique identifier for the record in UUID4 format")
    created_at: datetime = Field(..., alias="createdAt", description="Date and time with zone information, marks an **absolute point** on the timeline  - theoretically can be sent and received with any zone offset (until it marks the desired **absolute point** on the timeline) - in practice it is advised to transfer it in UTC timezone (with Z offset, \"Zulu time\") - ISO 8601 compliant string in `yyyy-mm-ddThh:mm:ss.SSSZ` format ")
    user: AuditLogUser = Field(...)
    domain: AuditLogDomain = Field(...)
    type: AuditLogType = Field(...)
    status: AuditLogStatus = Field(...)
    description: StrictStr = Field(...)
    impersonated_by_user: Optional[AuditLogUser] = Field(None, alias="impersonatedByUser")
    requested_with_api_key: Optional[AuditLogApiKey] = Field(None, alias="requestedWithApiKey")
    __properties = ["id", "createdAt", "user", "domain", "type", "status", "description", "impersonatedByUser", "requestedWithApiKey"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AuditLog:
        """Create an instance of AuditLog from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of user
        if self.user:
            _dict['user'] = self.user.to_dict()
        # override the default output from pydantic by calling `to_dict()` of impersonated_by_user
        if self.impersonated_by_user:
            _dict['impersonatedByUser'] = self.impersonated_by_user.to_dict()
        # override the default output from pydantic by calling `to_dict()` of requested_with_api_key
        if self.requested_with_api_key:
            _dict['requestedWithApiKey'] = self.requested_with_api_key.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AuditLog:
        """Create an instance of AuditLog from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AuditLog.parse_obj(obj)

        _obj = AuditLog.parse_obj({
            "id": obj.get("id"),
            "created_at": obj.get("createdAt"),
            "user": AuditLogUser.from_dict(obj.get("user")) if obj.get("user") is not None else None,
            "domain": obj.get("domain"),
            "type": obj.get("type"),
            "status": obj.get("status"),
            "description": obj.get("description"),
            "impersonated_by_user": AuditLogUser.from_dict(obj.get("impersonatedByUser")) if obj.get("impersonatedByUser") is not None else None,
            "requested_with_api_key": AuditLogApiKey.from_dict(obj.get("requestedWithApiKey")) if obj.get("requestedWithApiKey") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.116
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from helix_platform_api_public_client.models.participant_dashboard_next_nomination_gates import ParticipantDashboardNextNominationGates  # noqa: E501

class TestParticipantDashboardNextNominationGates(unittest.TestCase):
    """ParticipantDashboardNextNominationGates unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ParticipantDashboardNextNominationGates:
        """Test ParticipantDashboardNextNominationGates
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ParticipantDashboardNextNominationGates`
        """
        model = ParticipantDashboardNextNominationGates()  # noqa: E501
        if include_optional:
            return ParticipantDashboardNextNominationGates(
                nomination_gates = [
                    helix_platform_api_public_client.models.dashboard_next_nomination_gate.DashboardNextNominationGate(
                        timescale = 'LONG_TERM', 
                        window = helix_platform_api_public_client.models.dashboard_next_nomination_gate_window.DashboardNextNominationGate_window(
                            opens_at = '2022-01-04T00:00Z', 
                            closes_at = '2022-01-04T00:00Z', ), 
                        delivery_period = helix_platform_api_public_client.models.mtu_period.MtuPeriod(
                            from_mtu_start = '2022-01-04T10:00Z', 
                            to_mtu_end = '2022-01-04T11:00Z', ), 
                        status = 'NOT_YET_OPEN', 
                        next_action_at = '2022-01-04T00:00Z', )
                    ]
            )
        else:
            return ParticipantDashboardNextNominationGates(
                nomination_gates = [
                    helix_platform_api_public_client.models.dashboard_next_nomination_gate.DashboardNextNominationGate(
                        timescale = 'LONG_TERM', 
                        window = helix_platform_api_public_client.models.dashboard_next_nomination_gate_window.DashboardNextNominationGate_window(
                            opens_at = '2022-01-04T00:00Z', 
                            closes_at = '2022-01-04T00:00Z', ), 
                        delivery_period = helix_platform_api_public_client.models.mtu_period.MtuPeriod(
                            from_mtu_start = '2022-01-04T10:00Z', 
                            to_mtu_end = '2022-01-04T11:00Z', ), 
                        status = 'NOT_YET_OPEN', 
                        next_action_at = '2022-01-04T00:00Z', )
                    ],
        )
        """

    def testParticipantDashboardNextNominationGates(self):
        """Test ParticipantDashboardNextNominationGates"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.116
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import date

from pydantic import BaseModel, Field, StrictStr, constr, validator
from helix_platform_api_public_client.models.intra_day_product_type import IntraDayProductType
from helix_platform_api_public_client.models.local_mtu_period import LocalMtuPeriod
from helix_platform_api_public_client.models.nomination_gate_status import NominationGateStatus

class IntraDayNominationGate(BaseModel):
    """
    IntraDayNominationGate
    """
    id: constr(strict=True) = Field(..., description="Virtual ID of a \"Workflow\" in the following format `{recurringWorkflowId}:{executionDay}`  Example: `684df173-4110-4e0d-b364-d2364388afe3:2024-06-01` ")
    product_type: IntraDayProductType = Field(..., alias="productType")
    name: StrictStr = Field(...)
    delivery_day: date = Field(..., alias="deliveryDay", description="One single calendar day, interpreted in **System Time**  - ISO 8601 compliant string in `yyyy-mm-dd` format ")
    mtu_period: LocalMtuPeriod = Field(..., alias="mtuPeriod")
    status: NominationGateStatus = Field(...)
    __properties = ["id", "productType", "name", "deliveryDay", "mtuPeriod", "status"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> IntraDayNominationGate:
        """Create an instance of IntraDayNominationGate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of mtu_period
        if self.mtu_period:
            _dict['mtuPeriod'] = self.mtu_period.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> IntraDayNominationGate:
        """Create an instance of IntraDayNominationGate from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return IntraDayNominationGate.parse_obj(obj)

        _obj = IntraDayNominationGate.parse_obj({
            "id": obj.get("id"),
            "product_type": obj.get("productType"),
            "name": obj.get("name"),
            "delivery_day": obj.get("deliveryDay"),
            "mtu_period": LocalMtuPeriod.from_dict(obj.get("mtuPeriod")) if obj.get("mtuPeriod") is not None else None,
            "status": obj.get("status")
        })
        return _obj





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.116
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from helix_platform_api_public_client.models.error_response import ErrorResponse  # noqa: E501

class TestErrorResponse(unittest.TestCase):
    """ErrorResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ErrorResponse:
        """Test ErrorResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ErrorResponse`
        """
        model = ErrorResponse()  # noqa: E501
        if include_optional:
            return ErrorResponse(
                code = 'ACTIVE_UNPLANNED_OUTAGE_EXISTS',
                message = '',
                nested_errors = [
                    helix_platform_api_public_client.models.nested_error.NestedError(
                        field_name = '', 
                        code = '', 
                        message = '', )
                    ],
                params = {
                    'key' : ''
                    },
                request_id = '',
                debug_error = ''
            )
        else:
            return ErrorResponse(
                code = 'ACTIVE_UNPLANNED_OUTAGE_EXISTS',
        )
        """

    def testErrorResponse(self):
        """Test ErrorResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.116
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import re  # noqa: F401
import io
import warnings

from pydantic import validate_arguments, ValidationError

from typing_extensions import Annotated
from datetime import date

from pydantic import Field, StrictStr, conlist

from helix_platform_api_public_client.models.aggregated_nomination_options import AggregatedNominationOptions
from helix_platform_api_public_client.models.aggregated_nominations import AggregatedNominations
from helix_platform_api_public_client.models.aggregated_pre_nomination_options import AggregatedPreNominationOptions
from helix_platform_api_public_client.models.border_direction import BorderDirection
from helix_platform_api_public_client.models.submit_timescale_nominations_request import SubmitTimescaleNominationsRequest
from helix_platform_api_public_client.models.timescale import Timescale
from helix_platform_api_public_client.models.timescale_nomination_options import TimescaleNominationOptions
from helix_platform_api_public_client.models.timescale_nomination_type import TimescaleNominationType
from helix_platform_api_public_client.models.timescale_nominations import TimescaleNominations

from helix_platform_api_public_client.api_client import ApiClient
from helix_platform_api_public_client.api_response import ApiResponse
from helix_platform_api_public_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class NominationApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def get_aggregated_nomination_options(self, **kwargs) -> AggregatedNominationOptions:  # noqa: E501
        """get_aggregated_nomination_options  # noqa: E501

        Fetch options for Aggregated Nominations  Returns if the current Participant organisation is configured as \"nomination on behalf\" for any Markets. If yes, the list of \"nominees\" returned.  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_AGGREGATED_NOMINATIONS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_aggregated_nomination_options(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: AggregatedNominationOptions
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the get_aggregated_nomination_options_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.get_aggregated_nomination_options_with_http_info(**kwargs)  # noqa: E501

    @validate_arguments
    def get_aggregated_nomination_options_with_http_info(self, **kwargs) -> ApiResponse:  # noqa: E501
        """get_aggregated_nomination_options  # noqa: E501

        Fetch options for Aggregated Nominations  Returns if the current Participant organisation is configured as \"nomination on behalf\" for any Markets. If yes, the list of \"nominees\" returned.  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_AGGREGATED_NOMINATIONS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_aggregated_nomination_options_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(AggregatedNominationOptions, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_aggregated_nomination_options" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['ApiKey', 'AuthToken']  # noqa: E501

        _response_types_map = {
            '200': "AggregatedNominationOptions",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/v1/nominations/aggregated/options', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_aggregated_nominations(self, delivery_day : Annotated[date, Field(..., description="Delivery Day")], timescales : Annotated[conlist(Timescale), Field(..., description="List of Timescales")], x_participant_ids : Annotated[conlist(StrictStr), Field(..., description="List of internal IDs of Participant-type Organisations")], **kwargs) -> AggregatedNominations:  # noqa: E501
        """get_aggregated_nominations  # noqa: E501

        Fetch aggregated Nominatinons for a given:   - delivery day   - selected timescales   - participant(s)  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_AGGREGATED_NOMINATIONS`   * `VIEW_ANY_AGGREGATED_NOMINATIONS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_aggregated_nominations(delivery_day, timescales, x_participant_ids, async_req=True)
        >>> result = thread.get()

        :param delivery_day: Delivery Day (required)
        :type delivery_day: date
        :param timescales: List of Timescales (required)
        :type timescales: List[Timescale]
        :param x_participant_ids: List of internal IDs of Participant-type Organisations (required)
        :type x_participant_ids: List[str]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: AggregatedNominations
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the get_aggregated_nominations_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.get_aggregated_nominations_with_http_info(delivery_day, timescales, x_participant_ids, **kwargs)  # noqa: E501

    @validate_arguments
    def get_aggregated_nominations_with_http_info(self, delivery_day : Annotated[date, Field(..., description="Delivery Day")], timescales : Annotated[conlist(Timescale), Field(..., description="List of Timescales")], x_participant_ids : Annotated[conlist(StrictStr), Field(..., description="List of internal IDs of Participant-type Organisations")], **kwargs) -> ApiResponse:  # noqa: E501
        """get_aggregated_nominations  # noqa: E501

        Fetch aggregated Nominatinons for a given:   - delivery day   - selected timescales   - participant(s)  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_AGGREGATED_NOMINATIONS`   * `VIEW_ANY_AGGREGATED_NOMINATIONS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_aggregated_nominations_with_http_info(delivery_day, timescales, x_participant_ids, async_req=True)
        >>> result = thread.get()

        :param delivery_day: Delivery Day (required)
        :type delivery_day: date
        :param timescales: List of Timescales (required)
        :type timescales: List[Timescale]
        :param x_participant_ids: List of internal IDs of Participant-type Organisations (required)
        :type x_participant_ids: List[str]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(AggregatedNominations, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'delivery_day',
            'timescales',
            'x_participant_ids'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_aggregated_nominations" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('delivery_day') is not None:  # noqa: E501
            if isinstance(_params['delivery_day'], date):
                _query_params.append(('deliveryDay', _params['delivery_day'].isoformat()))
            else:
                _query_params.append(('deliveryDay', _params['delivery_day']))

        if _params.get('timescales') is not None:  # noqa: E501
            _query_params.append(('timescales', _params['timescales']))
            _collection_formats['timescales'] = 'multi'

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['x_participant_ids']:
            _header_params['X-Participant-Ids'] = _params['x_participant_ids']
            _collection_formats['X-Participant-Ids'] = 'csv'

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['ApiKey', 'AuthToken']  # noqa: E501

        _response_types_map = {
            '200': "AggregatedNominations",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/v1/nominations/aggregated', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_aggregated_pre_nomination_options(self, x_participant_id : Annotated[StrictStr, Field(..., description="Internal ID of a Participant-type Organisation")], delivery_day : Annotated[date, Field(..., description="Delivery Day")], **kwargs) -> AggregatedPreNominationOptions:  # noqa: E501
        """get_aggregated_pre_nomination_options  # noqa: E501

        Fetch pre-nomination options for Aggregated Nominations  Returns if the selected Participant organisation has pre-nominations defined for all the timescales for the given delivery day.  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_AGGREGATED_NOMINATIONS`   * `VIEW_ANY_AGGREGATED_NOMINATIONS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_aggregated_pre_nomination_options(x_participant_id, delivery_day, async_req=True)
        >>> result = thread.get()

        :param x_participant_id: Internal ID of a Participant-type Organisation (required)
        :type x_participant_id: str
        :param delivery_day: Delivery Day (required)
        :type delivery_day: date
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: AggregatedPreNominationOptions
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the get_aggregated_pre_nomination_options_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.get_aggregated_pre_nomination_options_with_http_info(x_participant_id, delivery_day, **kwargs)  # noqa: E501

    @validate_arguments
    def get_aggregated_pre_nomination_options_with_http_info(self, x_participant_id : Annotated[StrictStr, Field(..., description="Internal ID of a Participant-type Organisation")], delivery_day : Annotated[date, Field(..., description="Delivery Day")], **kwargs) -> ApiResponse:  # noqa: E501
        """get_aggregated_pre_nomination_options  # noqa: E501

        Fetch pre-nomination options for Aggregated Nominations  Returns if the selected Participant organisation has pre-nominations defined for all the timescales for the given delivery day.  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_AGGREGATED_NOMINATIONS`   * `VIEW_ANY_AGGREGATED_NOMINATIONS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_aggregated_pre_nomination_options_with_http_info(x_participant_id, delivery_day, async_req=True)
        >>> result = thread.get()

        :param x_participant_id: Internal ID of a Participant-type Organisation (required)
        :type x_participant_id: str
        :param delivery_day: Delivery Day (required)
        :type delivery_day: date
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(AggregatedPreNominationOptions, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'x_participant_id',
            'delivery_day'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_aggregated_pre_nomination_options" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('delivery_day') is not None:  # noqa: E501
            if isinstance(_params['delivery_day'], date):
                _query_params.append(('deliveryDay', _params['delivery_day'].isoformat()))
            else:
                _query_params.append(('deliveryDay', _params['delivery_day']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['x_participant_id']:
            _header_params['X-Participant-Id'] = _params['x_participant_id']

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['ApiKey', 'AuthToken']  # noqa: E501

        _response_types_map = {
            '200': "AggregatedPreNominationOptions",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/v1/nominations/aggregated/options/pre-nominations', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_nomination_options(self, delivery_day : Annotated[date, Field(..., description="Delivery Day")], type : TimescaleNominationType, x_participant_id : Annotated[StrictStr, Field(..., description="Internal ID of a Participant-type Organisation")], **kwargs) -> TimescaleNominationOptions:  # noqa: E501
        """get_nomination_options  # noqa: E501

        Fetch options for getting Nominations  Used to determine which are the available directions for which a given Participant has rights to nominate for a given:   - delivery day   - type of nomination  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_NOMINATIONS`   * `VIEW_ANY_NOMINATIONS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_nomination_options(delivery_day, type, x_participant_id, async_req=True)
        >>> result = thread.get()

        :param delivery_day: Delivery Day (required)
        :type delivery_day: date
        :param type: (required)
        :type type: TimescaleNominationType
        :param x_participant_id: Internal ID of a Participant-type Organisation (required)
        :type x_participant_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: TimescaleNominationOptions
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the get_nomination_options_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.get_nomination_options_with_http_info(delivery_day, type, x_participant_id, **kwargs)  # noqa: E501

    @validate_arguments
    def get_nomination_options_with_http_info(self, delivery_day : Annotated[date, Field(..., description="Delivery Day")], type : TimescaleNominationType, x_participant_id : Annotated[StrictStr, Field(..., description="Internal ID of a Participant-type Organisation")], **kwargs) -> ApiResponse:  # noqa: E501
        """get_nomination_options  # noqa: E501

        Fetch options for getting Nominations  Used to determine which are the available directions for which a given Participant has rights to nominate for a given:   - delivery day   - type of nomination  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_NOMINATIONS`   * `VIEW_ANY_NOMINATIONS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_nomination_options_with_http_info(delivery_day, type, x_participant_id, async_req=True)
        >>> result = thread.get()

        :param delivery_day: Delivery Day (required)
        :type delivery_day: date
        :param type: (required)
        :type type: TimescaleNominationType
        :param x_participant_id: Internal ID of a Participant-type Organisation (required)
        :type x_participant_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(TimescaleNominationOptions, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'delivery_day',
            'type',
            'x_participant_id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_nomination_options" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('delivery_day') is not None:  # noqa: E501
            if isinstance(_params['delivery_day'], date):
                _query_params.append(('deliveryDay', _params['delivery_day'].isoformat()))
            else:
                _query_params.append(('deliveryDay', _params['delivery_day']))

        if _params.get('type') is not None:  # noqa: E501
            _query_params.append(('type', _params['type'].value))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['x_participant_id']:
            _header_params['X-Participant-Id'] = _params['x_participant_id']

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['ApiKey', 'AuthToken']  # noqa: E501

        _response_types_map = {
            '200': "TimescaleNominationOptions",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/v1/nominations/options', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_nominations(self, delivery_day : Annotated[date, Field(..., description="Delivery Day")], type : TimescaleNominationType, x_participant_id : Annotated[StrictStr, Field(..., description="Internal ID of a Participant-type Organisation")], border_direction : Annotated[BorderDirection, Field(..., description="Border Direction")], **kwargs) -> TimescaleNominations:  # noqa: E501
        """get_nominations  # noqa: E501

        Fetch current Nominations for a given:   - delivery day   - type of nomination   - particpant   - border direction  MTUs are returned in the timescale's \"Nomination MTU Size\" resolution  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_NOMINATIONS`   * `VIEW_ANY_NOMINATIONS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_nominations(delivery_day, type, x_participant_id, border_direction, async_req=True)
        >>> result = thread.get()

        :param delivery_day: Delivery Day (required)
        :type delivery_day: date
        :param type: (required)
        :type type: TimescaleNominationType
        :param x_participant_id: Internal ID of a Participant-type Organisation (required)
        :type x_participant_id: str
        :param border_direction: Border Direction (required)
        :type border_direction: BorderDirection
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: TimescaleNominations
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the get_nominations_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.get_nominations_with_http_info(delivery_day, type, x_participant_id, border_direction, **kwargs)  # noqa: E501

    @validate_arguments
    def get_nominations_with_http_info(self, delivery_day : Annotated[date, Field(..., description="Delivery Day")], type : TimescaleNominationType, x_participant_id : Annotated[StrictStr, Field(..., description="Internal ID of a Participant-type Organisation")], border_direction : Annotated[BorderDirection, Field(..., description="Border Direction")], **kwargs) -> ApiResponse:  # noqa: E501
        """get_nominations  # noqa: E501

        Fetch current Nominations for a given:   - delivery day   - type of nomination   - particpant   - border direction  MTUs are returned in the timescale's \"Nomination MTU Size\" resolution  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_NOMINATIONS`   * `VIEW_ANY_NOMINATIONS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_nominations_with_http_info(delivery_day, type, x_participant_id, border_direction, async_req=True)
        >>> result = thread.get()

        :param delivery_day: Delivery Day (required)
        :type delivery_day: date
        :param type: (required)
        :type type: TimescaleNominationType
        :param x_participant_id: Internal ID of a Participant-type Organisation (required)
        :type x_participant_id: str
        :param border_direction: Border Direction (required)
        :type border_direction: BorderDirection
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(TimescaleNominations, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'delivery_day',
            'type',
            'x_participant_id',
            'border_direction'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_nominations" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('delivery_day') is not None:  # noqa: E501
            if isinstance(_params['delivery_day'], date):
                _query_params.append(('deliveryDay', _params['delivery_day'].isoformat()))
            else:
                _query_params.append(('deliveryDay', _params['delivery_day']))

        if _params.get('type') is not None:  # noqa: E501
            _query_params.append(('type', _params['type'].value))

        if _params.get('border_direction') is not None:  # noqa: E501
            _query_params.append(('borderDirection', _params['border_direction'].value))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['x_participant_id']:
            _header_params['X-Participant-Id'] = _params['x_participant_id']

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['ApiKey', 'AuthToken']  # noqa: E501

        _response_types_map = {
            '200': "TimescaleNominations",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/v1/nominations', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def submit_nominations(self, delivery_day : Annotated[date, Field(..., description="Delivery Day")], type : TimescaleNominationType, x_participant_id : Annotated[StrictStr, Field(..., description="Internal ID of a Participant-type Organisation")], border_direction : Annotated[BorderDirection, Field(..., description="Border Direction")], submit_timescale_nominations_request : SubmitTimescaleNominationsRequest, **kwargs) -> None:  # noqa: E501
        """submit_nominations  # noqa: E501

        Submit Nominations for the given:   - delivery day   - type of nomination   - particpant   - border direction  ---  __Requires Permission:__ (at least one)   * `MANAGE_OWN_NOMINATIONS`   * `MANAGE_ANY_NOMINATIONS`  __Generates Audit Log Entry:__ `SUBMIT_NOMINATIONS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.submit_nominations(delivery_day, type, x_participant_id, border_direction, submit_timescale_nominations_request, async_req=True)
        >>> result = thread.get()

        :param delivery_day: Delivery Day (required)
        :type delivery_day: date
        :param type: (required)
        :type type: TimescaleNominationType
        :param x_participant_id: Internal ID of a Participant-type Organisation (required)
        :type x_participant_id: str
        :param border_direction: Border Direction (required)
        :type border_direction: BorderDirection
        :param submit_timescale_nominations_request: (required)
        :type submit_timescale_nominations_request: SubmitTimescaleNominationsRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the submit_nominations_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.submit_nominations_with_http_info(delivery_day, type, x_participant_id, border_direction, submit_timescale_nominations_request, **kwargs)  # noqa: E501

    @validate_arguments
    def submit_nominations_with_http_info(self, delivery_day : Annotated[date, Field(..., description="Delivery Day")], type : TimescaleNominationType, x_participant_id : Annotated[StrictStr, Field(..., description="Internal ID of a Participant-type Organisation")], border_direction : Annotated[BorderDirection, Field(..., description="Border Direction")], submit_timescale_nominations_request : SubmitTimescaleNominationsRequest, **kwargs) -> ApiResponse:  # noqa: E501
        """submit_nominations  # noqa: E501

        Submit Nominations for the given:   - delivery day   - type of nomination   - particpant   - border direction  ---  __Requires Permission:__ (at least one)   * `MANAGE_OWN_NOMINATIONS`   * `MANAGE_ANY_NOMINATIONS`  __Generates Audit Log Entry:__ `SUBMIT_NOMINATIONS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.submit_nominations_with_http_info(delivery_day, type, x_participant_id, border_direction, submit_timescale_nominations_request, async_req=True)
        >>> result = thread.get()

        :param delivery_day: Delivery Day (required)
        :type delivery_day: date
        :param type: (required)
        :type type: TimescaleNominationType
        :param x_participant_id: Internal ID of a Participant-type Organisation (required)
        :type x_participant_id: str
        :param border_direction: Border Direction (required)
        :type border_direction: BorderDirection
        :param submit_timescale_nominations_request: (required)
        :type submit_timescale_nominations_request: SubmitTimescaleNominationsRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'delivery_day',
            'type',
            'x_participant_id',
            'border_direction',
            'submit_timescale_nominations_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method submit_nominations" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('delivery_day') is not None:  # noqa: E501
            if isinstance(_params['delivery_day'], date):
                _query_params.append(('deliveryDay', _params['delivery_day'].isoformat()))
            else:
                _query_params.append(('deliveryDay', _params['delivery_day']))

        if _params.get('type') is not None:  # noqa: E501
            _query_params.append(('type', _params['type'].value))

        if _params.get('border_direction') is not None:  # noqa: E501
            _query_params.append(('borderDirection', _params['border_direction'].value))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['x_participant_id']:
            _header_params['X-Participant-Id'] = _params['x_participant_id']

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['submit_timescale_nominations_request'] is not None:
            _body_params = _params['submit_timescale_nominations_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['ApiKey', 'AuthToken']  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/v1/nominations', 'PUT',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.116
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class UserRole(str, Enum):
    """
    UserRole
    """

    """
    allowed enum values
    """
    ICO_ADMIN = 'ICO_ADMIN'
    ICO_CURTAILMENT_MANAGER = 'ICO_CURTAILMENT_MANAGER'
    ICO_VIEW = 'ICO_VIEW'
    PART_ADMIN = 'PART_ADMIN'
    PART_NOMINATOR = 'PART_NOMINATOR'
    PART_VIEW = 'PART_VIEW'

    @classmethod
    def from_json(cls, json_str: str) -> UserRole:
        """Create an instance of UserRole from a JSON string"""
        return UserRole(json.loads(json_str))





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.116
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field
from helix_platform_api_public_client.models.long_term_or_day_ahead_nomination_gate import LongTermOrDayAheadNominationGate

class NominationGatesOverviewResponseDayAhead(BaseModel):
    """
    NominationGatesOverviewResponseDayAhead
    """
    gate: LongTermOrDayAheadNominationGate = Field(...)
    next_action_at: Optional[datetime] = Field(None, alias="nextActionAt", description="Date and time with zone information, marks an **absolute point** on the timeline  - theoretically can be sent and received with any zone offset (until it marks the desired **absolute point** on the timeline) - in practice it is advised to transfer it in UTC timezone (with Z offset, \"Zulu time\") - ISO 8601 compliant string in `yyyy-mm-ddThh:mm:ss.SSSZ` format ")
    __properties = ["gate", "nextActionAt"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> NominationGatesOverviewResponseDayAhead:
        """Create an instance of NominationGatesOverviewResponseDayAhead from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of gate
        if self.gate:
            _dict['gate'] = self.gate.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> NominationGatesOverviewResponseDayAhead:
        """Create an instance of NominationGatesOverviewResponseDayAhead from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return NominationGatesOverviewResponseDayAhead.parse_obj(obj)

        _obj = NominationGatesOverviewResponseDayAhead.parse_obj({
            "gate": LongTermOrDayAheadNominationGate.from_dict(obj.get("gate")) if obj.get("gate") is not None else None,
            "next_action_at": obj.get("nextActionAt")
        })
        return _obj





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.116
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class Permission(str, Enum):
    """
    Permission
    """

    """
    allowed enum values
    """
    VIEW_CAPACITY_OVERVIEW = 'VIEW_CAPACITY_OVERVIEW'
    VIEW_NTC_OVERVIEW = 'VIEW_NTC_OVERVIEW'
    VIEW_ATC_OVERVIEW = 'VIEW_ATC_OVERVIEW'
    MANAGE_NTC = 'MANAGE_NTC'
    MANAGE_ATC = 'MANAGE_ATC'
    VIEW_UNPLANNED_OUTAGES = 'VIEW_UNPLANNED_OUTAGES'
    MANAGE_UNPLANNED_OUTAGES = 'MANAGE_UNPLANNED_OUTAGES'
    VIEW_PLANNED_OUTAGES = 'VIEW_PLANNED_OUTAGES'
    MANAGE_PLANNED_OUTAGES = 'MANAGE_PLANNED_OUTAGES'
    VIEW_OWN_TRANSMISSION_RIGHTS = 'VIEW_OWN_TRANSMISSION_RIGHTS'
    VIEW_ANY_TRANSMISSION_RIGHTS = 'VIEW_ANY_TRANSMISSION_RIGHTS'
    VIEW_OWN_NOMINATIONS = 'VIEW_OWN_NOMINATIONS'
    VIEW_ANY_NOMINATIONS = 'VIEW_ANY_NOMINATIONS'
    MANAGE_OWN_NOMINATIONS = 'MANAGE_OWN_NOMINATIONS'
    MANAGE_ANY_NOMINATIONS = 'MANAGE_ANY_NOMINATIONS'
    VIEW_NOMINATION_GATES_OVERVIEW = 'VIEW_NOMINATION_GATES_OVERVIEW'
    MANAGE_NOMINATION_CANCELLATION = 'MANAGE_NOMINATION_CANCELLATION'
    VIEW_CURTAILMENT = 'VIEW_CURTAILMENT'
    MANAGE_CURTAILMENT = 'MANAGE_CURTAILMENT'
    VIEW_OWN_AGGREGATED_NOMINATIONS = 'VIEW_OWN_AGGREGATED_NOMINATIONS'
    VIEW_ANY_AGGREGATED_NOMINATIONS = 'VIEW_ANY_AGGREGATED_NOMINATIONS'
    VIEW_OWN_DEFAULT_NOMINATIONS = 'VIEW_OWN_DEFAULT_NOMINATIONS'
    MANAGE_OWN_DEFAULT_NOMINATIONS = 'MANAGE_OWN_DEFAULT_NOMINATIONS'
    VIEW_ANY_DEFAULT_NOMINATIONS = 'VIEW_ANY_DEFAULT_NOMINATIONS'
    MANAGE_ANY_DEFAULT_NOMINATIONS = 'MANAGE_ANY_DEFAULT_NOMINATIONS'
    VIEW_CRISIS = 'VIEW_CRISIS'
    MANAGE_CRISIS_ACTIONS = 'MANAGE_CRISIS_ACTIONS'
    MANAGE_CRISIS_MESSAGES = 'MANAGE_CRISIS_MESSAGES'
    MANAGE_ANY_ORGANISATIONS = 'MANAGE_ANY_ORGANISATIONS'
    VIEW_OWN_ORGANISATIONS = 'VIEW_OWN_ORGANISATIONS'
    VIEW_ANY_ORGANISATIONS = 'VIEW_ANY_ORGANISATIONS'
    VIEW_OWN_USERS = 'VIEW_OWN_USERS'
    VIEW_ANY_USERS = 'VIEW_ANY_USERS'
    MANAGE_OWN_USERS = 'MANAGE_OWN_USERS'
    MANAGE_ANY_USERS = 'MANAGE_ANY_USERS'
    INVITE_OWN_USERS = 'INVITE_OWN_USERS'
    INVITE_ANY_USERS = 'INVITE_ANY_USERS'
    IMPERSONATE_USERS = 'IMPERSONATE_USERS'
    VIEW_ICO_DASHBOARD = 'VIEW_ICO_DASHBOARD'
    VIEW_PARTICIPANT_DASHBOARD = 'VIEW_PARTICIPANT_DASHBOARD'
    VIEW_GENERAL_SYSTEM_MESSAGES = 'VIEW_GENERAL_SYSTEM_MESSAGES'
    VIEW_OPERATIONAL_SYSTEM_MESSAGES = 'VIEW_OPERATIONAL_SYSTEM_MESSAGES'
    VIEW_PARTICIPANT_MESSAGES = 'VIEW_PARTICIPANT_MESSAGES'
    VIEW_BPP = 'VIEW_BPP'
    MANAGE_BPP = 'MANAGE_BPP'
    VIEW_BUSINESS_PROCESSES = 'VIEW_BUSINESS_PROCESSES'
    MANAGE_BUSINESS_PROCESSES = 'MANAGE_BUSINESS_PROCESSES'
    MANAGE_SENSITIVE_BUSINESS_PROCESSES = 'MANAGE_SENSITIVE_BUSINESS_PROCESSES'
    VIEW_DATA_FLOWS = 'VIEW_DATA_FLOWS'
    MANAGE_DATA_FLOWS = 'MANAGE_DATA_FLOWS'
    MANAGE_OWN_MANUAL_FILE_UPLOAD = 'MANAGE_OWN_MANUAL_FILE_UPLOAD'
    MANAGE_ANY_MANUAL_FILE_UPLOAD = 'MANAGE_ANY_MANUAL_FILE_UPLOAD'
    VIEW_OWN_AUDIT_LOGS = 'VIEW_OWN_AUDIT_LOGS'
    VIEW_ANY_AUDIT_LOGS = 'VIEW_ANY_AUDIT_LOGS'
    VIEW_BUSINESS_SETTINGS = 'VIEW_BUSINESS_SETTINGS'
    MANAGE_BUSINESS_SETTINGS = 'MANAGE_BUSINESS_SETTINGS'
    VIEW_PROTECTED_CONFIG_VARIABLES = 'VIEW_PROTECTED_CONFIG_VARIABLES'
    VIEW_HELP_FAQ = 'VIEW_HELP_FAQ'

    @classmethod
    def from_json(cls, json_str: str) -> Permission:
        """Create an instance of Permission from a JSON string"""
        return Permission(json.loads(json_str))


